@@ -381,7 +381,7 @@ class KpAnalysisUtils:
     @staticmethod
     def graph_data_to_hierarchical(result_graph_data_json,
                                    filter_small_nodes=-1,
-                                   filter_min_relations=0.2,
+                                   filter_min_relations=-1,
                                    filter_big_to_small_edges=True,
                                    save_hierarchical_textual_bullets=True,
                                    save_hierarchical_graph_data=True):
